@@ -1,7 +1,8 @@
 controlBMAgamma <-
 function(maxIter = Inf, tol = sqrt(.Machine$double.eps), 
          power = 1, startupSpeed = NULL,
-         init = list(varCoefs = NULL, weights = NULL)) 
+         init = list(varCoefs = NULL, weights = NULL),
+         optim.control = list(ndeps = rep(sqrt(.Machine$double.eps),2))) 
 {
 #
 # copyright 2006-present, University of Washington. All rights reserved.
@@ -10,6 +11,6 @@ function(maxIter = Inf, tol = sqrt(.Machine$double.eps),
 
  if (is.infinite(maxIter) && maxIter > 0) maxIter <- .Machine$integer.max
  list(maxIter = maxIter, tol = tol, power = power, startupSpeed = startupSpeed,
-      init = init) 
+      init = init, optim.control = optim.control) 
 }
 
