@@ -154,9 +154,10 @@ function(ensembleData, trainingDays, dates = NULL,
  structure(list(training = list(days=trainingDays,lag=lag,table=trainTable), 
                 prob0coefs = prob0coefs, biasCoefs = biasCoefs, 
                 varCoefs = varCoefs, weights = weights, nIter = nIter,
-                exchangeable = exchangeable, power = fit$power),
+                exchangeable = exchangeable, power = fit$power,
+		call = match.call()),
                 forecastHour = forecastHour, 
                 initializationTime = ensembleItime(ensembleData),
-                call = match.call(), class = c("ensembleBMAgamma0","ensembleBMA"))
+                class = c("ensembleBMAgamma0","ensembleBMA"))
 }
 
