@@ -16,13 +16,6 @@ ensembleData <- ensembleData[,matchEnsembleMembers(fit,ensembleData)]
  M <- !dataNA(ensembleData,dates=FALSE)
  if (!all(M)) ensembleData <- ensembleData[M,]
 
- fitDates <- modelDates(fit)
-
- M <- matchDates( fitDates, ensembleValidDates(ensembleData), dates = NULL)
-
- if (!all(M$ens)) ensembleData <- ensembleData[M$ens,]
- if (!all(M$fit)) fit <- fit[fitDates[M$fit]]
-
  obs <- dataVerifObs(ensembleData)
  nObs <- length(obs)
 
